@@ -8,14 +8,30 @@ from drf_spectacular.views import (
 
 from nautobot.core.api.views import (
     APIRootView,
-    StatusView,
+    GetFilterSetFieldDOMElementAPIView,
+    GetFilterSetFieldLookupExpressionChoicesAPIView,
     GraphQLDRFAPIView,
+    StatusView,
     NautobotSpectacularSwaggerView,
     NautobotSpectacularRedocView,
 )
 from nautobot.extras.plugins.urls import plugin_api_patterns
 
 
+core_api_patterns = [
+    # Lookup Expr
+    path(
+        "filterset-fields/lookup-choices/",
+        GetFilterSetFieldLookupExpressionChoicesAPIView.as_view(),
+        name="filtersetfield-list-lookupchoices",
+    ),
+    path(
+        "filterset-fields/lookup-value-dom-element/",
+        GetFilterSetFieldDOMElementAPIView.as_view(),
+        name="filtersetfield-retrieve-lookupvaluedomelement",
+    ),
+]
+
 urlpatterns = [
     # Base views
     path("", APIRootView.as_view(), name="api-root"),
@@ -36,4 +52,6 @@ urlpatterns = [
     path("graphql/", GraphQLDRFAPIView.as_view(), name="graphql-api"),
     # Plugins
     path("plugins/", include((plugin_api_patterns, "plugins-api"))),
+    # Core
+    path("core/", include((core_api_patterns, "core-api"))),
 ]
