@@ -311,7 +311,7 @@ class NautobotViewSetMixin(GenericViewSet, AccessMixin, GetReturnURLMixin, FormV
     def get_filter_params(self, request):
         """Helper function - take request.GET and discard any parameters that are not used for queryset filtering."""
         filter_params = request.GET.copy()
-        return get_filterable_params_from_filter_params(filter_params, self.non_filter_params, self.filterset_class)
+        return get_filterable_params_from_filter_params(filter_params, self.non_filter_params, self.filterset_class())
 
     def get_queryset(self):
         """
