@@ -2,6 +2,7 @@ from collections import OrderedDict
 
 import yaml
 from django.contrib.contenttypes.fields import GenericRelation
+from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ValidationError
 from django.core.serializers.json import DjangoJSONEncoder
 from django.core.validators import MaxValueValidator, MinValueValidator
@@ -10,7 +11,7 @@ from django.db.models import F, ProtectedError, Q
 from django.urls import reverse
 from django.utils.safestring import mark_safe
 
-from nautobot.dcim.choices import DeviceFaceChoices, SubdeviceRoleChoices
+from nautobot.dcim.choices import DeviceFaceChoices, DeviceRedundancyGroupFailoverStrategyChoices, SubdeviceRoleChoices
 
 from nautobot.extras.models import ConfigContextModel, StatusModel
 from nautobot.extras.querysets import ConfigContextModelQuerySet
@@ -34,6 +35,7 @@ from .device_components import (
 
 __all__ = (
     "Device",
+    "DeviceRedundancyGroup",
     "DeviceRole",
     "DeviceType",
     "Manufacturer",
@@ -106,15 +108,18 @@ class DeviceType(PrimaryModel):
 
     manufacturer = models.ForeignKey(to="dcim.Manufacturer", on_delete=models.PROTECT, related_name="device_types")
     model = models.CharField(max_length=100)
-    # TODO: Remove unique=None to make slug globally unique. This would be a breaking change.
+    # 2.0 TODO: Remove unique=None to make slug globally unique. This would be a breaking change.
     slug = AutoSlugField(populate_from="model", unique=None, db_index=True)
     part_number = models.CharField(max_length=50, blank=True, help_text="Discrete part number (optional)")
+    # 2.0 TODO: Profile filtering on this field if it could benefit from an index
     u_height = models.PositiveSmallIntegerField(default=1, verbose_name="Height (U)")
+    # todoindex:
     is_full_depth = models.BooleanField(
         default=True,
         verbose_name="Is full depth",
         help_text="Device consumes both front and rear rack faces",
     )
+    # todoindex:
     subdevice_role = models.CharField(
         max_length=50,
         choices=SubdeviceRoleChoices,
@@ -138,7 +143,7 @@ class DeviceType(PrimaryModel):
         ordering = ["manufacturer", "model"]
         unique_together = [
             ["manufacturer", "model"],
-            # TODO: Remove unique_together to make slug globally unique. This would be a breaking change.
+            # 2.0 TODO: Remove unique_together to make slug globally unique. This would be a breaking change.
             ["manufacturer", "slug"],
         ]
 
@@ -262,8 +267,7 @@ class DeviceType(PrimaryModel):
                 if d.position not in u_available:
                     raise ValidationError(
                         {
-                            "u_height": "Device {} in rack {} does not have sufficient space to accommodate a height of "
-                            "{}U".format(d, d.rack, self.u_height)
+                            "u_height": f"Device {d} in rack {d.rack} does not have sufficient space to accommodate a height of {self.u_height}U"
                         }
                     )
 
@@ -293,7 +297,7 @@ class DeviceType(PrimaryModel):
             raise ValidationError({"u_height": "Child device types must be 0U."})
 
     def save(self, *args, **kwargs):
-        ret = super().save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
         # Delete any previously uploaded image files that are no longer in use
         if self._original_front_image and self.front_image != self._original_front_image:
@@ -301,8 +305,6 @@ class DeviceType(PrimaryModel):
         if self._original_rear_image and self.rear_image != self._original_rear_image:
             self._original_rear_image.delete(save=False)
 
-        return ret
-
     def delete(self, *args, **kwargs):
         super().delete(*args, **kwargs)
 
@@ -341,6 +343,7 @@ class DeviceRole(OrganizationalModel):
     name = models.CharField(max_length=100, unique=True)
     slug = AutoSlugField(populate_from="name")
     color = ColorField(default=ColorChoices.COLOR_GREY)
+    # todoindex:
     vm_role = models.BooleanField(
         default=True,
         verbose_name="VM Role",
@@ -441,17 +444,19 @@ class Platform(OrganizationalModel):
     "dynamic_groups",
     "export_templates",
     "graphql",
+    "locations",
     "relationships",
     "statuses",
     "webhooks",
 )
 class Device(PrimaryModel, ConfigContextModel, StatusModel):
     """
-    A Device represents a piece of physical hardware mounted within a Rack. Each Device is assigned a DeviceType,
+    A Device represents a piece of physical hardware. Each Device is assigned a DeviceType,
     DeviceRole, and (optionally) a Platform. Device names are not required, however if one is set it must be unique.
 
-    Each Device must be assigned to a site, and optionally to a rack within that site. Associating a device with a
-    particular rack face or unit is optional (for example, vertically mounted PDUs do not consume rack units).
+    Each Device must be assigned to a Site and/or Location, and optionally to a Rack within that.
+    Associating a device with a particular rack face or unit is optional (for example, vertically mounted PDUs
+    do not consume rack units).
 
     When a new Device is created, console/power/interface/device bay components are created along with it as dictated
     by the component templates assigned to its DeviceType. Components can also be added, modified, or deleted after the
@@ -486,6 +491,13 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         help_text="A unique tag used to identify this device",
     )
     site = models.ForeignKey(to="dcim.Site", on_delete=models.PROTECT, related_name="devices")
+    location = models.ForeignKey(
+        to="dcim.Location",
+        on_delete=models.PROTECT,
+        related_name="devices",
+        blank=True,
+        null=True,
+    )
     rack = models.ForeignKey(
         to="dcim.Rack",
         on_delete=models.PROTECT,
@@ -493,6 +505,7 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         blank=True,
         null=True,
     )
+    # 2.0 TODO: Profile filtering on this field if it could benefit from an index
     position = models.PositiveSmallIntegerField(
         blank=True,
         null=True,
@@ -500,6 +513,7 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         verbose_name="Position (U)",
         help_text="The lowest-numbered unit occupied by the device",
     )
+    # todoindex:
     face = models.CharField(max_length=50, blank=True, choices=DeviceFaceChoices, verbose_name="Rack face")
     primary_ip4 = models.OneToOneField(
         to="ipam.IPAddress",
@@ -531,6 +545,22 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         blank=True,
         null=True,
     )
+    device_redundancy_group = models.ForeignKey(
+        to="dcim.DeviceRedundancyGroup",
+        on_delete=models.SET_NULL,
+        related_name="members",
+        blank=True,
+        null=True,
+        verbose_name="Device Redundancy Group",
+    )
+    device_redundancy_group_priority = models.PositiveSmallIntegerField(
+        blank=True,
+        null=True,
+        validators=[MinValueValidator(1)],
+        verbose_name="Device Redundancy Group Priority",
+        help_text="The priority the device has in the device redundancy group.",
+    )
+    # 2.0 TODO: Profile filtering on this field if it could benefit from an index
     vc_position = models.PositiveSmallIntegerField(blank=True, null=True, validators=[MaxValueValidator(255)])
     vc_priority = models.PositiveSmallIntegerField(blank=True, null=True, validators=[MaxValueValidator(255)])
     comments = models.TextField(blank=True)
@@ -557,10 +587,13 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         "asset_tag",
         "status",
         "site",
+        "location",
         "rack_group",
         "rack_name",
         "position",
         "face",
+        "device_redundancy_group",
+        "device_redundancy_group_priority",
         "secrets_group",
         "primary_ip",
         "comments",
@@ -571,6 +604,7 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         "tenant",
         "platform",
         "site",
+        "location",
         "rack",
         "status",
         "cluster",
@@ -613,6 +647,23 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
                 }
             )
 
+        # Validate location
+        if self.location is not None:
+            if self.location.base_site != self.site:
+                raise ValidationError(
+                    {"location": f'Location "{self.location}" does not belong to site "{self.site}".'}
+                )
+
+            if self.rack is not None and self.rack.location is not None and self.rack.location != self.location:
+                raise ValidationError({"rack": f'Rack "{self.rack}" does not belong to location "{self.location}".'})
+
+            # self.cluster is validated somewhat later, see below
+
+            if ContentType.objects.get_for_model(self) not in self.location.location_type.content_types.all():
+                raise ValidationError(
+                    {"location": f'Devices may not associate to locations of type "{self.location.location_type}".'}
+                )
+
         if self.rack is None:
             if self.face:
                 raise ValidationError(
@@ -713,15 +764,28 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
             if self.platform.manufacturer and self.platform.manufacturer != self.device_type.manufacturer:
                 raise ValidationError(
                     {
-                        "platform": "The assigned platform is limited to {} device types, but this device's type belongs "
-                        "to {}.".format(self.platform.manufacturer, self.device_type.manufacturer)
+                        "platform": (
+                            f"The assigned platform is limited to {self.platform.manufacturer} device types, "
+                            f"but this device's type belongs to {self.device_type.manufacturer}."
+                        )
                     }
                 )
 
         # A Device can only be assigned to a Cluster in the same Site (or no Site)
         if self.cluster and self.cluster.site is not None and self.cluster.site != self.site:
             raise ValidationError(
-                {"cluster": "The assigned cluster belongs to a different site ({})".format(self.cluster.site)}
+                {"cluster": f"The assigned cluster belongs to a different site ({self.cluster.site})"}
+            )
+
+        # A Device can only be assigned to a Cluster in the same location or parent location, if any
+        if (
+            self.cluster is not None
+            and self.location is not None
+            and self.cluster.location is not None
+            and self.cluster.location not in self.location.ancestors(include_self=True)
+        ):
+            raise ValidationError(
+                {"cluster": f"The assigned cluster belongs to a location that does not include {self.location}."}
             )
 
         # Validate virtual chassis assignment
@@ -736,12 +800,17 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
             if existing_virtual_chassis and existing_virtual_chassis.master == self:
                 raise ValidationError(
                     {
-                        "virtual_chassis": "The master device for the virtual chassis ({}) may not be removed".format(
-                            existing_virtual_chassis
-                        )
+                        "virtual_chassis": f"The master device for the virtual chassis ({ existing_virtual_chassis}) may not be removed"
                     }
                 )
 
+        if self.device_redundancy_group_priority is not None and self.device_redundancy_group is None:
+            raise ValidationError(
+                {
+                    "device_redundancy_group_priority": "Must assign a redundancy group when defining a redundancy group priority."
+                }
+            )
+
     def save(self, *args, **kwargs):
 
         is_new = not self.present_in_database
@@ -780,10 +849,13 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
             self.asset_tag,
             self.get_status_display(),
             self.site.name,
+            self.location.name if self.location else None,
             self.rack.group.name if self.rack and self.rack.group else None,
             self.rack.name if self.rack else None,
             self.position,
             self.get_face_display(),
+            self.device_redundancy_group.slug if self.device_redundancy_group else None,
+            self.device_redundancy_group_priority,
             self.secrets_group.name if self.secrets_group else None,
             self.primary_ip if self.primary_ip else None,
             self.comments,
@@ -807,7 +879,7 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         """
         if self.name is not None:
             return self.name
-        return "{{{}}}".format(self.pk)
+        return f"{{{self.pk}}}"
 
     @property
     def primary_ip(self):
@@ -832,10 +904,20 @@ class Device(PrimaryModel, ConfigContextModel, StatusModel):
         Return a QuerySet matching all Interfaces assigned to this Device or, if this Device is a VC master, to another
         Device belonging to the same VirtualChassis.
         """
-        filter = Q(device=self)
+        filter_q = Q(device=self)
         if self.virtual_chassis and self.virtual_chassis.master == self:
-            filter |= Q(device__virtual_chassis=self.virtual_chassis, mgmt_only=False)
-        return Interface.objects.filter(filter)
+            filter_q |= Q(device__virtual_chassis=self.virtual_chassis, mgmt_only=False)
+        return Interface.objects.filter(filter_q)
+
+    @property
+    def common_vc_interfaces(self):
+        """
+        Return a QuerySet matching all Interfaces assigned to this Device or,
+        if this Device belongs to a VirtualChassis, it returns all interfaces belonging Devices with same VirtualChassis
+        """
+        if self.virtual_chassis:
+            return self.virtual_chassis.member_interfaces
+        return self.interfaces
 
     def get_cables(self, pk_list=False):
         """
@@ -908,6 +990,11 @@ class VirtualChassis(PrimaryModel):
     def get_absolute_url(self):
         return reverse("dcim:virtualchassis", kwargs={"pk": self.pk})
 
+    @property
+    def member_interfaces(self):
+        """Return a list of Interfaces common to all member devices."""
+        return Interface.objects.filter(pk__in=self.members.values_list("interfaces", flat=True))
+
     def clean(self):
         super().clean()
 
@@ -938,3 +1025,71 @@ class VirtualChassis(PrimaryModel):
             self.domain,
             self.master.name if self.master else None,
         )
+
+
+@extras_features(
+    "custom_fields",
+    "custom_links",
+    "custom_validators",
+    "dynamic_groups",
+    "export_templates",
+    "graphql",
+    "relationships",
+    "statuses",
+    "webhooks",
+)
+class DeviceRedundancyGroup(PrimaryModel, StatusModel):
+    """
+    A DeviceRedundancyGroup represents a logical grouping of physical hardware for the purposes of high-availability.
+    """
+
+    name = models.CharField(max_length=100, unique=True)
+    slug = AutoSlugField(populate_from="name")
+    description = models.CharField(max_length=200, blank=True)
+
+    failover_strategy = models.CharField(
+        max_length=50,
+        blank=True,
+        choices=DeviceRedundancyGroupFailoverStrategyChoices,
+        verbose_name="Failover strategy",
+    )
+
+    comments = models.TextField(blank=True)
+
+    secrets_group = models.ForeignKey(
+        to="extras.SecretsGroup",
+        on_delete=models.SET_NULL,
+        default=None,
+        blank=True,
+        null=True,
+    )
+
+    clone_fields = [
+        "failover_strategy",
+        "status",
+        "secrets_group",
+    ]
+
+    csv_headers = ["name", "failover_strategy", "status", "secrets_group", "comments"]
+
+    class Meta:
+        ordering = ("name",)
+
+    @property
+    def members_sorted(self):
+        return self.members.order_by("device_redundancy_group_priority")
+
+    def __str__(self):
+        return self.name
+
+    def get_absolute_url(self):
+        return reverse("dcim:deviceredundancygroup", args=[self.slug])
+
+    def to_csv(self):
+        return (
+            self.name,
+            self.failover_strategy,
+            self.get_status_display(),
+            self.secrets_group.name if self.secrets_group else None,
+            self.comments,
+        )
