@@ -27,6 +27,7 @@ from nautobot.utilities.forms import (
     DatePicker,
     JSONField,
     LaxURLField,
+    NullableDateField,
     StaticSelect2,
     StaticSelect2Multiple,
     add_blank_choice,
@@ -139,6 +140,7 @@ class CustomFieldModel(models.Model):
 
     def get_custom_fields_basic(self):
         """
+        This method exists to help call get_custom_fields() in templates where a function argument (advanced_ui) cannot be specified.
         Return a dictionary of custom fields for a single object in the form {<field>: value}
         which have advanced_ui set to False
         """
@@ -146,6 +148,7 @@ class CustomFieldModel(models.Model):
 
     def get_custom_fields_advanced(self):
         """
+        This method exists to help call get_custom_fields() in templates where a function argument (advanced_ui) cannot be specified.
         Return a dictionary of custom fields for a single object in the form {<field>: value}
         which have advanced_ui set to True
         """
@@ -161,6 +164,55 @@ class CustomFieldModel(models.Model):
         # 2.0 TODO: #824 field.slug rather than field.name
         return OrderedDict([(field, self.cf.get(field.name)) for field in fields])
 
+    def get_custom_field_groupings_basic(self):
+        """
+        This method exists to help call get_custom_field_groupings() in templates where a function argument (advanced_ui) cannot be specified.
+        Return a dictonary of custom fields grouped by the same grouping in the form
+        {
+            <grouping_1>: [(cf1, <value for cf1>), (cf2, <value for cf2>), ...],
+            ...
+            <grouping_5>: [(cf8, <value for cf8>), (cf9, <value for cf9>), ...],
+            ...
+        }
+        which have advanced_ui set to False
+        """
+        return self.get_custom_field_groupings(advanced_ui=False)
+
+    def get_custom_field_groupings_advanced(self):
+        """
+        This method exists to help call get_custom_field_groupings() in templates where a function argument (advanced_ui) cannot be specified.
+        Return a dictonary of custom fields grouped by the same grouping in the form
+        {
+            <grouping_1>: [(cf1, <value for cf1>), (cf2, <value for cf2>), ...],
+            ...
+            <grouping_5>: [(cf8, <value for cf8>), (cf9, <value for cf9>), ...],
+            ...
+        }
+        which have advanced_ui set to True
+        """
+        return self.get_custom_field_groupings(advanced_ui=True)
+
+    def get_custom_field_groupings(self, advanced_ui=None):
+        """
+        Return a dictonary of custom fields grouped by the same grouping in the form
+        {
+            <grouping_1>: [(cf1, <value for cf1>), (cf2, <value for cf2>), ...],
+            ...
+            <grouping_5>: [(cf8, <value for cf8>), (cf9, <value for cf9>), ...],
+            ...
+        }
+        """
+        record = {}
+        fields = CustomField.objects.get_for_model(self)
+        if advanced_ui is not None:
+            fields = fields.filter(advanced_ui=advanced_ui)
+
+        for field in fields:
+            data = (field, self.cf.get(field.name))
+            record.setdefault(field.grouping, []).append(data)
+        record = dict(sorted(record.items()))
+        return record
+
     def clean(self):
         super().clean()
 
@@ -251,6 +303,11 @@ class CustomField(BaseModel, ChangeLoggedModel, NotesMixin):
         limit_choices_to=FeatureQuery("custom_fields"),
         help_text="The object(s) to which this field applies.",
     )
+    grouping = models.CharField(
+        max_length=255,
+        blank=True,
+        help_text="Human-readable grouping that this custom field belongs to.",
+    )
     type = models.CharField(
         max_length=50,
         choices=CustomFieldTypeChoices,
@@ -325,6 +382,20 @@ class CustomField(BaseModel, ChangeLoggedModel, NotesMixin):
 
     objects = CustomFieldManager()
 
+    clone_fields = [
+        "content_types",
+        "grouping",
+        "type",
+        "description",
+        "required",
+        "filter_logic",
+        "default",
+        "weight",
+        "validation_minimum",
+        "validation_maximum",
+        "validation_regex",
+    ]
+
     class Meta:
         ordering = ["weight", "name"]
 
@@ -385,14 +456,8 @@ class CustomField(BaseModel, ChangeLoggedModel, NotesMixin):
         if self.validation_maximum is not None and self.type != CustomFieldTypeChoices.TYPE_INTEGER:
             raise ValidationError({"validation_maximum": "A maximum value may be set only for numeric fields"})
 
-        # Regex validation can be set only for text fields
-        regex_types = (
-            CustomFieldTypeChoices.TYPE_TEXT,
-            CustomFieldTypeChoices.TYPE_URL,
-            CustomFieldTypeChoices.TYPE_SELECT,
-            CustomFieldTypeChoices.TYPE_MULTISELECT,
-        )
-        if self.validation_regex and self.type not in regex_types:
+        # Regex validation can be set only for text, url, select and multi-select fields
+        if self.validation_regex and self.type not in CustomFieldTypeChoices.REGEX_TYPES:
             raise ValidationError(
                 {"validation_regex": "Regular expression validation is supported only for text, URL and select fields"}
             )
@@ -414,12 +479,12 @@ class CustomField(BaseModel, ChangeLoggedModel, NotesMixin):
                 {"default": f"The specified default value ({self.default}) is not listed as an available choice."}
             )
 
-    def save(self, **kwargs):
+    def save(self, *args, **kwargs):
         # Prior to Nautobot 1.4, `slug` was a non-existent field, but now it's mandatory.
         # Protect against get_or_create() or other ORM usage where callers aren't calling clean() before saving.
         # Normally we'd just say "Don't do that!" but we know there are some cases of this in the wild.
         self._fixup_empty_fields()
-        super().save(**kwargs)
+        super().save(*args, **kwargs)
 
     def to_form_field(
         self, set_initial=True, enforce_required=True, for_csv_import=False, simple_json_filter=False, label=None
@@ -459,15 +524,19 @@ class CustomField(BaseModel, ChangeLoggedModel, NotesMixin):
 
         # Date
         elif self.type == CustomFieldTypeChoices.TYPE_DATE:
-            field = forms.DateField(required=required, initial=initial, widget=DatePicker())
+            field = NullableDateField(
+                required=required,
+                initial=initial,
+                widget=DatePicker(),
+            )
 
-        # URL
-        elif self.type == CustomFieldTypeChoices.TYPE_URL:
-            field = LaxURLField(required=required, initial=initial)
+        # Text and URL
+        elif self.type in (CustomFieldTypeChoices.TYPE_URL, CustomFieldTypeChoices.TYPE_TEXT):
+            if self.type == CustomFieldTypeChoices.TYPE_URL:
+                field = LaxURLField(required=required, initial=initial)
+            elif self.type == CustomFieldTypeChoices.TYPE_TEXT:
+                field = forms.CharField(max_length=255, required=required, initial=initial)
 
-        # Text
-        elif self.type == CustomFieldTypeChoices.TYPE_TEXT:
-            field = forms.CharField(max_length=255, required=required, initial=initial)
             if self.validation_regex:
                 field.validators = [
                     RegexValidator(
@@ -527,12 +596,12 @@ class CustomField(BaseModel, ChangeLoggedModel, NotesMixin):
         if value not in [None, "", []]:
 
             # Validate text field
-            if self.type == CustomFieldTypeChoices.TYPE_TEXT:
+            if self.type in (CustomFieldTypeChoices.TYPE_TEXT, CustomFieldTypeChoices.TYPE_URL):
 
                 if not isinstance(value, str):
                     raise ValidationError("Value must be a string")
 
-                if self.validation_regex and not re.match(self.validation_regex, value):
+                if self.validation_regex and not re.search(self.validation_regex, value):
                     raise ValidationError(f"Value must match regex '{self.validation_regex}'")
 
             # Validate integer
@@ -625,7 +694,7 @@ class CustomFieldChoice(BaseModel, ChangeLoggedModel):
         if self.field.type not in (CustomFieldTypeChoices.TYPE_SELECT, CustomFieldTypeChoices.TYPE_MULTISELECT):
             raise ValidationError("Custom field choices can only be assigned to selection fields.")
 
-        if not re.match(self.field.validation_regex, self.value):
+        if not re.search(self.field.validation_regex, self.value):
             raise ValidationError(f"Value must match regex {self.field.validation_regex} got {self.value}.")
 
     def save(self, *args, **kwargs):
@@ -652,11 +721,13 @@ class CustomFieldChoice(BaseModel, ChangeLoggedModel):
             # Cannot delete the choice if it is the default value.
             if self.field.type == CustomFieldTypeChoices.TYPE_SELECT and self.field.default == self.value:
                 raise models.ProtectedError(
-                    self, "Cannot delete this choice because it is the default value for the field."
+                    msg="Cannot delete this choice because it is the default value for the field.",
+                    protected_objects=[self],  # TODO: should this be self.field instead?
                 )
             elif self.value in self.field.default:
                 raise models.ProtectedError(
-                    self, "Cannot delete this choice because it is one of the default values for the field."
+                    msg="Cannot delete this choice because it is one of the default values for the field.",
+                    protected_objects=[self],  # TODO: should this be self.field instead?
                 )
 
         if self.field.type == CustomFieldTypeChoices.TYPE_SELECT:
@@ -665,7 +736,10 @@ class CustomFieldChoice(BaseModel, ChangeLoggedModel):
                 model = ct.model_class()
                 # 2.0 TODO: #824 self.field.slug instead of self.field.name
                 if model.objects.filter(**{f"_custom_field_data__{self.field.name}": self.value}).exists():
-                    raise models.ProtectedError(self, "Cannot delete this choice because it is in active use.")
+                    raise models.ProtectedError(
+                        msg="Cannot delete this choice because it is in active use.",
+                        protected_objects=[self],  # TODO should this be model.objects.filter(...) instead?
+                    )
 
         else:
             # Check if this value is in active use in a multi-select field
@@ -673,11 +747,14 @@ class CustomFieldChoice(BaseModel, ChangeLoggedModel):
                 model = ct.model_class()
                 # 2.0 TODO: #824 self.field.slug instead of self.field.name
                 if model.objects.filter(**{f"_custom_field_data__{self.field.name}__contains": self.value}).exists():
-                    raise models.ProtectedError(self, "Cannot delete this choice because it is in active use.")
+                    raise models.ProtectedError(
+                        msg="Cannot delete this choice because it is in active use.",
+                        protected_objects=[self],  # TODO should this be model.objects.filter(...) instead?
+                    )
 
         super().delete(*args, **kwargs)
 
-    def to_objectchange(self, action):
+    def to_objectchange(self, action, related_object=None, **kwargs):
         # Annotate the parent field
         try:
             field = self.field
@@ -685,4 +762,4 @@ class CustomFieldChoice(BaseModel, ChangeLoggedModel):
             # The parent field has already been deleted
             field = None
 
-        return super().to_objectchange(action, related_object=field)
+        return super().to_objectchange(action, related_object=field, **kwargs)
