@@ -1,3 +1,5 @@
+from django.conf import settings
+
 from nautobot.dcim.models import DeviceRole
 from nautobot.extras.jobs import Job, BooleanVar, IntegerVar, StringVar, ObjectVar
 
@@ -6,6 +8,7 @@ class APITestJob(Job):
     class Meta:
         name = "Job for API Tests"
         has_sensitive_variables = False
+        task_queues = [settings.CELERY_TASK_DEFAULT_QUEUE, "nonexistent"]
 
     var1 = StringVar()
     var2 = IntegerVar(required=True)  # explicitly stated, though required=True is the default in any case
