@@ -4,15 +4,18 @@ import warnings
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth import get_user_model
 from django.db.models import Q
-from django.test import TestCase
+from django.test import TestCase, override_settings
 
 from nautobot.dcim.forms import DeviceForm, SiteBulkEditForm, SiteForm
 import nautobot.dcim.models as dcim_models
 from nautobot.extras.choices import RelationshipTypeChoices
 from nautobot.extras.forms import (
+    ConfigContextForm,
+    ConfigContextFilterForm,
     CustomFieldModelBulkEditFormMixin,
     CustomFieldModelFilterFormMixin,
     CustomFieldModelFormMixin,
+    JobButtonForm,
     JobEditForm,
     JobHookForm,
     RelationshipModelFormMixin,
@@ -21,7 +24,7 @@ from nautobot.extras.forms import (
     TagsBulkEditFormMixin,
     WebhookForm,
 )
-from nautobot.extras.models import Job, JobHook, Note, Relationship, RelationshipAssociation, Status, Webhook
+from nautobot.extras.models import Job, JobButton, JobHook, Note, Relationship, RelationshipAssociation, Status, Webhook
 from nautobot.ipam.forms import IPAddressForm, IPAddressBulkEditForm, VLANGroupForm
 import nautobot.ipam.models as ipam_models
 
@@ -149,6 +152,68 @@ class JobHookFormTestCase(TestCase):
         )
 
 
+class JobButtonFormTestCase(TestCase):
+    @classmethod
+    def setUpTestData(cls):
+        job_button = JobButton.objects.create(
+            name="JobButton1",
+            text="JobButton1",
+            job=Job.objects.get(job_class_name="TestJobButtonReceiverComplex"),
+        )
+        device_ct = ContentType.objects.get_for_model(dcim_models.Device)
+        site_ct = ContentType.objects.get_for_model(dcim_models.Site)
+        job_button.content_types.set([device_ct])
+
+        cls.job_buttons_data = (
+            {
+                "name": "JobButton2",
+                "text": "JobButton2",
+                "content_types": [device_ct.pk],
+                "job": Job.objects.get(job_class_name="TestJobButtonReceiverSimple"),
+                "weight": 100,
+                "button_class": "primary",
+            },
+            {
+                "name": "JobButton3",
+                "text": "JobButton3",
+                "content_types": [site_ct.pk],
+                "job": Job.objects.get(job_class_name="TestJobButtonReceiverComplex"),
+                "weight": 100,
+                "button_class": "primary",
+            },
+        )
+
+    def test_create_job_button_with_same_content_type_diff_job(self):
+        """
+        Create a new job button with the same content_types and different job from a job button that exists
+
+        Example:
+            Job button 1: dcim | device, Job(job_class_name="TestJobButtonReceiverComplex")
+            Job button 2: dcim | device, Job(job_class_name="TestJobButtonReceiverSimple")
+        """
+        form = JobButtonForm(data=self.job_buttons_data[0])
+
+        self.assertTrue(form.is_valid(), form.errors)
+        form.save()
+
+        self.assertEqual(JobButton.objects.filter(name=self.job_buttons_data[0]["name"]).count(), 1)
+
+    def test_create_job_button_with_same_job_diff_content_type(self):
+        """
+        Create a new job button with the same job and different content types from a job button that exists
+
+        Example:
+            Job button 1: dcim | device, Job(job_class_name="TestJobButtonReceiverComplex")
+            Job button 2: dcim | site, Job(job_class_name="TestJobButtonReceiverComplex")
+        """
+        form = JobButtonForm(data=self.job_buttons_data[1])
+
+        self.assertTrue(form.is_valid(), form.errors)
+        form.save()
+
+        self.assertEqual(JobButton.objects.filter(name=self.job_buttons_data[1]["name"]).count(), 1)
+
+
 class NoteModelFormTestCase(TestCase):
     """
     TestNoteModelForm validation and saving.
@@ -1086,3 +1151,31 @@ class JobEditFormTestCase(TestCase):
             error_msg["approval_required"][0]["message"],
             "A job that may have sensitive variables cannot be marked as requiring approval",
         )
+
+
+class ConfigContextFormTestCase(TestCase):
+    @override_settings(CONFIG_CONTEXT_DYNAMIC_GROUPS_ENABLED=True)
+    def test_with_dynamic_groups(self):
+        """Asserts that `ConfigContextForm.dynamic_group` is present when feature flag is enabled."""
+        form = ConfigContextForm()
+        self.assertIn("dynamic_groups", form.fields)
+
+    @override_settings(CONFIG_CONTEXT_DYNAMIC_GROUPS_ENABLED=False)
+    def test_without_dynamic_groups(self):
+        """Asserts that `ConfigContextForm.dynamic_group` is NOT present when feature flag is disabled."""
+        form = ConfigContextForm()
+        self.assertNotIn("dynamic_groups", form.fields)
+
+
+class ConfigContextFilterFormTestCase(TestCase):
+    @override_settings(CONFIG_CONTEXT_DYNAMIC_GROUPS_ENABLED=True)
+    def test_with_dynamic_groups(self):
+        """Asserts that `ConfigContextForm.dynamic_group` is present when feature flag is enabled."""
+        context_filter_form = ConfigContextFilterForm()
+        self.assertIn("dynamic_groups", context_filter_form.fields)
+
+    @override_settings(CONFIG_CONTEXT_DYNAMIC_GROUPS_ENABLED=False)
+    def test_without_dynamic_groups(self):
+        """Asserts that `ConfigContextFilterForm.dynamic_group` is NOT present when feature flag is disabled."""
+        context_filter_form = ConfigContextFilterForm()
+        self.assertNotIn("dynamic_groups", context_filter_form.fields)
