@@ -92,23 +92,19 @@ class ClusterFilterSet(NautobotFilterSet, LocatableModelFilterSetMixin, TenancyM
     )
     group_id = django_filters.ModelMultipleChoiceFilter(
         queryset=ClusterGroup.objects.all(),
-        label="Parent group (ID)",
+        label="Parent group (ID) - Deprecated (use group filter)",
     )
-    group = django_filters.ModelMultipleChoiceFilter(
-        field_name="group__slug",
+    group = NaturalKeyOrPKMultipleChoiceFilter(
         queryset=ClusterGroup.objects.all(),
-        to_field_name="slug",
-        label="Parent group (slug)",
+        label="Parent group (ID or slug)",
     )
     type_id = django_filters.ModelMultipleChoiceFilter(
         queryset=ClusterType.objects.all(),
-        label="Cluster type (ID)",
+        label="Cluster type (ID) - Deprecated (use type filter)",
     )
-    type = django_filters.ModelMultipleChoiceFilter(
-        field_name="type__slug",
+    type = NaturalKeyOrPKMultipleChoiceFilter(
         queryset=ClusterType.objects.all(),
-        to_field_name="slug",
-        label="Cluster type (slug)",
+        label="Cluster type (ID or slug)",
     )
     tag = TagFilter()
 
@@ -132,24 +128,22 @@ class VirtualMachineFilterSet(
     cluster_group_id = django_filters.ModelMultipleChoiceFilter(
         field_name="cluster__group",
         queryset=ClusterGroup.objects.all(),
-        label="Cluster group (ID)",
+        label="Cluster group (ID) - Deprecated (use cluster_group filter)",
     )
-    cluster_group = django_filters.ModelMultipleChoiceFilter(
-        field_name="cluster__group__slug",
+    cluster_group = NaturalKeyOrPKMultipleChoiceFilter(
+        field_name="cluster__group",
         queryset=ClusterGroup.objects.all(),
-        to_field_name="slug",
-        label="Cluster group (slug)",
+        label="Cluster group (ID or slug)",
     )
     cluster_type_id = django_filters.ModelMultipleChoiceFilter(
         field_name="cluster__type",
         queryset=ClusterType.objects.all(),
-        label="Cluster type (ID)",
+        label="Cluster type (ID) - Deprecated (use cluster_type filter)",
     )
-    cluster_type = django_filters.ModelMultipleChoiceFilter(
-        field_name="cluster__type__slug",
+    cluster_type = NaturalKeyOrPKMultipleChoiceFilter(
+        field_name="cluster__type",
         queryset=ClusterType.objects.all(),
-        to_field_name="slug",
-        label="Cluster type (slug)",
+        label="Cluster type (ID or slug)",
     )
     cluster_id = django_filters.ModelMultipleChoiceFilter(
         queryset=Cluster.objects.all(),
@@ -169,13 +163,12 @@ class VirtualMachineFilterSet(
     site_id = django_filters.ModelMultipleChoiceFilter(
         field_name="cluster__site",
         queryset=Site.objects.all(),
-        label="Site (ID)",
+        label="Site (ID) - Deprecated (use site filter)",
     )
-    site = django_filters.ModelMultipleChoiceFilter(
-        field_name="cluster__site__slug",
+    site = NaturalKeyOrPKMultipleChoiceFilter(
+        field_name="cluster__site",
         queryset=Site.objects.all(),
-        to_field_name="slug",
-        label="Site (slug)",
+        label="Site (ID or slug)",
     )
     location = TreeNodeMultipleChoiceFilter(
         queryset=Location.objects.all(),
@@ -185,23 +178,19 @@ class VirtualMachineFilterSet(
     )
     role_id = django_filters.ModelMultipleChoiceFilter(
         queryset=DeviceRole.objects.all(),
-        label="Role (ID)",
+        label="Role (ID) - Deprecated (use role filter)",
     )
-    role = django_filters.ModelMultipleChoiceFilter(
-        field_name="role__slug",
+    role = NaturalKeyOrPKMultipleChoiceFilter(
         queryset=DeviceRole.objects.all(),
-        to_field_name="slug",
-        label="Role (slug)",
+        label="Role (ID or slug)",
     )
     platform_id = django_filters.ModelMultipleChoiceFilter(
         queryset=Platform.objects.all(),
-        label="Platform (ID)",
+        label="Platform (ID) - Deprecated (use platform filter)",
     )
-    platform = django_filters.ModelMultipleChoiceFilter(
-        field_name="platform__slug",
+    platform = NaturalKeyOrPKMultipleChoiceFilter(
         queryset=Platform.objects.all(),
-        to_field_name="slug",
-        label="Platform (slug)",
+        label="Platform (ID or slug)",
     )
     mac_address = MultiValueMACAddressFilter(
         field_name="interfaces__mac_address",
@@ -271,24 +260,23 @@ class VMInterfaceFilterSet(BaseFilterSet, StatusModelFilterSetMixin, CustomField
     cluster_id = django_filters.ModelMultipleChoiceFilter(
         field_name="virtual_machine__cluster",
         queryset=Cluster.objects.all(),
-        label="Cluster (ID)",
+        label="Cluster (ID) - Deprecated (use cluster filter)",
     )
-    cluster = django_filters.ModelMultipleChoiceFilter(
-        field_name="virtual_machine__cluster__name",
+    cluster = NaturalKeyOrPKMultipleChoiceFilter(
+        field_name="virtual_machine__cluster",
         queryset=Cluster.objects.all(),
         to_field_name="name",
-        label="Cluster",
+        label="Cluster (ID or name)",
     )
     virtual_machine_id = django_filters.ModelMultipleChoiceFilter(
         field_name="virtual_machine",
         queryset=VirtualMachine.objects.all(),
-        label="Virtual machine (ID)",
+        label="Virtual machine (ID) - Deprecated (use virtual_machine filter)",
     )
-    virtual_machine = django_filters.ModelMultipleChoiceFilter(
-        field_name="virtual_machine__name",
+    virtual_machine = NaturalKeyOrPKMultipleChoiceFilter(
         queryset=VirtualMachine.objects.all(),
         to_field_name="name",
-        label="Virtual machine",
+        label="Virtual machine (ID or name)",
     )
     parent_interface = NaturalKeyOrPKMultipleChoiceFilter(
         to_field_name="name",
