@@ -2,6 +2,7 @@ from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ValidationError
 from django.test import TestCase
 
+from nautobot.dcim.choices import InterfaceModeChoices
 from nautobot.dcim.models import Location, LocationType, Site
 from nautobot.extras.models import Status
 from nautobot.ipam.models import VLAN
@@ -79,6 +80,9 @@ class VMInterfaceTestCase(TestCase):
         clustertype = ClusterType.objects.create(name="Test Cluster Type 1", slug="test-cluster-type-1")
         cluster = Cluster.objects.create(name="Test Cluster 1", type=clustertype)
         self.virtualmachine = VirtualMachine.objects.create(cluster=cluster, name="Test VM 1")
+        self.other_site_vlan = VLAN.objects.create(
+            name="Other Site VLAN", vid=100, site=Site.objects.create(name="Other Site")
+        )
 
     def test_tagged_vlan_raise_error_if_mode_not_set_to_tagged(self):
         interface = VMInterface.objects.create(virtual_machine=self.virtualmachine, name="Interface 1")
@@ -87,3 +91,17 @@ class VMInterfaceTestCase(TestCase):
         self.assertEqual(
             err.exception.message_dict["tagged_vlans"][0], "Mode must be set to tagged when specifying tagged_vlans"
         )
+
+    def test_error_raised_when_adding_tagged_vlan_with_different_site_from_interface_parent_site(self):
+        with self.assertRaises(ValidationError) as err:
+            interface = VMInterface.objects.create(
+                name="Test Interface",
+                mode=InterfaceModeChoices.MODE_TAGGED,
+                virtual_machine=self.virtualmachine,
+            )
+            interface.tagged_vlans.add(self.other_site_vlan)
+        self.assertEqual(
+            err.exception.message_dict["tagged_vlans"][0],
+            f"Tagged VLAN with names {[self.other_site_vlan.name]} must all belong to the "
+            f"same site as the interface's parent device, or it must be global.",
+        )
